# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file './Glucid8824.ui'
#
# Created by: PyQt5 UI code generator 5.11.2
#
# WARNING! All changes made in this file will be lost!

from PyQt5 import QtCore, QtGui, QtWidgets

class Ui_MainWindow(object):
    def setupUi(self, MainWindow):
        MainWindow.setObjectName("MainWindow")
        MainWindow.setEnabled(True)
        MainWindow.resize(901, 473)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(MainWindow.sizePolicy().hasHeightForWidth())
        MainWindow.setSizePolicy(sizePolicy)
        MainWindow.setMinimumSize(QtCore.QSize(901, 470))
        MainWindow.setMaximumSize(QtCore.QSize(901, 516))
        icon = QtGui.QIcon()
        icon.addPixmap(QtGui.QPixmap(":/newPrefix/lucid8824_icon.bmp"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        icon.addPixmap(QtGui.QPixmap(":/newPrefix/lucid8824_icon.bmp"), QtGui.QIcon.Normal, QtGui.QIcon.On)
        icon.addPixmap(QtGui.QPixmap(":/newPrefix/lucid8824_icon.bmp"), QtGui.QIcon.Disabled, QtGui.QIcon.Off)
        icon.addPixmap(QtGui.QPixmap(":/newPrefix/lucid8824_icon.bmp"), QtGui.QIcon.Disabled, QtGui.QIcon.On)
        icon.addPixmap(QtGui.QPixmap(":/newPrefix/lucid8824_icon.bmp"), QtGui.QIcon.Active, QtGui.QIcon.Off)
        icon.addPixmap(QtGui.QPixmap(":/newPrefix/lucid8824_icon.bmp"), QtGui.QIcon.Active, QtGui.QIcon.On)
        icon.addPixmap(QtGui.QPixmap(":/newPrefix/lucid8824_icon.bmp"), QtGui.QIcon.Selected, QtGui.QIcon.Off)
        icon.addPixmap(QtGui.QPixmap(":/newPrefix/lucid8824_icon.bmp"), QtGui.QIcon.Selected, QtGui.QIcon.On)
        MainWindow.setWindowIcon(icon)
        self.centralwidget = xglucidWidget(MainWindow)
        self.centralwidget.setObjectName("centralwidget")
        self.label = QtWidgets.QLabel(self.centralwidget)
        self.label.setEnabled(False)
        self.label.setGeometry(QtCore.QRect(-1, 0, 901, 471))
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Minimum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.label.sizePolicy().hasHeightForWidth())
        self.label.setSizePolicy(sizePolicy)
        self.label.setMaximumSize(QtCore.QSize(901, 471))
        self.label.setContextMenuPolicy(QtCore.Qt.NoContextMenu)
        self.label.setStyleSheet("background-image: url(:/newPrefix/glucidLayout3-nosig.png);")
        self.label.setMidLineWidth(1)
        self.label.setText("")
        self.label.setObjectName("label")
        self.SliderIN_1 = QtWidgets.QSlider(self.centralwidget)
        self.SliderIN_1.setEnabled(False)
        self.SliderIN_1.setGeometry(QtCore.QRect(286, 73, 21, 138))
        self.SliderIN_1.setAutoFillBackground(False)
        self.SliderIN_1.setMinimum(-95)
        self.SliderIN_1.setMaximum(31)
        self.SliderIN_1.setProperty("value", 0)
        self.SliderIN_1.setSliderPosition(0)
        self.SliderIN_1.setOrientation(QtCore.Qt.Vertical)
        self.SliderIN_1.setObjectName("SliderIN_1")
        self.SliderIN_2 = QtWidgets.QSlider(self.centralwidget)
        self.SliderIN_2.setEnabled(False)
        self.SliderIN_2.setGeometry(QtCore.QRect(342, 73, 21, 138))
        self.SliderIN_2.setMinimum(-95)
        self.SliderIN_2.setMaximum(31)
        self.SliderIN_2.setProperty("value", 0)
        self.SliderIN_2.setSliderPosition(0)
        self.SliderIN_2.setOrientation(QtCore.Qt.Vertical)
        self.SliderIN_2.setObjectName("SliderIN_2")
        self.SliderIN_3 = QtWidgets.QSlider(self.centralwidget)
        self.SliderIN_3.setEnabled(False)
        self.SliderIN_3.setGeometry(QtCore.QRect(397, 73, 21, 138))
        self.SliderIN_3.setMinimum(-95)
        self.SliderIN_3.setMaximum(31)
        self.SliderIN_3.setProperty("value", 0)
        self.SliderIN_3.setSliderPosition(0)
        self.SliderIN_3.setOrientation(QtCore.Qt.Vertical)
        self.SliderIN_3.setObjectName("SliderIN_3")
        self.SliderIN_6 = QtWidgets.QSlider(self.centralwidget)
        self.SliderIN_6.setEnabled(False)
        self.SliderIN_6.setGeometry(QtCore.QRect(560, 73, 21, 138))
        self.SliderIN_6.setMinimum(-95)
        self.SliderIN_6.setMaximum(31)
        self.SliderIN_6.setProperty("value", 0)
        self.SliderIN_6.setSliderPosition(0)
        self.SliderIN_6.setOrientation(QtCore.Qt.Vertical)
        self.SliderIN_6.setObjectName("SliderIN_6")
        self.SliderIN_4 = QtWidgets.QSlider(self.centralwidget)
        self.SliderIN_4.setEnabled(False)
        self.SliderIN_4.setGeometry(QtCore.QRect(452, 73, 21, 138))
        self.SliderIN_4.setMinimum(-95)
        self.SliderIN_4.setMaximum(31)
        self.SliderIN_4.setProperty("value", 0)
        self.SliderIN_4.setSliderPosition(0)
        self.SliderIN_4.setOrientation(QtCore.Qt.Vertical)
        self.SliderIN_4.setObjectName("SliderIN_4")
        self.SliderIN_5 = QtWidgets.QSlider(self.centralwidget)
        self.SliderIN_5.setEnabled(False)
        self.SliderIN_5.setGeometry(QtCore.QRect(506, 73, 21, 138))
        self.SliderIN_5.setMinimum(-95)
        self.SliderIN_5.setMaximum(31)
        self.SliderIN_5.setProperty("value", 0)
        self.SliderIN_5.setSliderPosition(0)
        self.SliderIN_5.setOrientation(QtCore.Qt.Vertical)
        self.SliderIN_5.setObjectName("SliderIN_5")
        self.SliderIN_7 = QtWidgets.QSlider(self.centralwidget)
        self.SliderIN_7.setEnabled(False)
        self.SliderIN_7.setGeometry(QtCore.QRect(616, 73, 21, 138))
        self.SliderIN_7.setMinimum(-95)
        self.SliderIN_7.setMaximum(31)
        self.SliderIN_7.setProperty("value", 0)
        self.SliderIN_7.setSliderPosition(0)
        self.SliderIN_7.setOrientation(QtCore.Qt.Vertical)
        self.SliderIN_7.setObjectName("SliderIN_7")
        self.SliderIN_8 = QtWidgets.QSlider(self.centralwidget)
        self.SliderIN_8.setEnabled(False)
        self.SliderIN_8.setGeometry(QtCore.QRect(671, 73, 21, 138))
        self.SliderIN_8.setMinimum(-95)
        self.SliderIN_8.setMaximum(31)
        self.SliderIN_8.setProperty("value", 0)
        self.SliderIN_8.setSliderPosition(0)
        self.SliderIN_8.setOrientation(QtCore.Qt.Vertical)
        self.SliderIN_8.setObjectName("SliderIN_8")
        self.SliderOUT_3 = QtWidgets.QSlider(self.centralwidget)
        self.SliderOUT_3.setEnabled(False)
        self.SliderOUT_3.setGeometry(QtCore.QRect(397, 275, 20, 138))
        self.SliderOUT_3.setMinimum(-95)
        self.SliderOUT_3.setMaximum(31)
        self.SliderOUT_3.setProperty("value", 0)
        self.SliderOUT_3.setOrientation(QtCore.Qt.Vertical)
        self.SliderOUT_3.setObjectName("SliderOUT_3")
        self.SliderOUT_1 = QtWidgets.QSlider(self.centralwidget)
        self.SliderOUT_1.setEnabled(False)
        self.SliderOUT_1.setGeometry(QtCore.QRect(287, 275, 21, 138))
        self.SliderOUT_1.setMinimum(-95)
        self.SliderOUT_1.setMaximum(31)
        self.SliderOUT_1.setProperty("value", 0)
        self.SliderOUT_1.setOrientation(QtCore.Qt.Vertical)
        self.SliderOUT_1.setInvertedAppearance(False)
        self.SliderOUT_1.setObjectName("SliderOUT_1")
        self.SliderOUT_8 = QtWidgets.QSlider(self.centralwidget)
        self.SliderOUT_8.setEnabled(False)
        self.SliderOUT_8.setGeometry(QtCore.QRect(672, 275, 21, 138))
        self.SliderOUT_8.setMinimum(-95)
        self.SliderOUT_8.setMaximum(31)
        self.SliderOUT_8.setProperty("value", 0)
        self.SliderOUT_8.setOrientation(QtCore.Qt.Vertical)
        self.SliderOUT_8.setObjectName("SliderOUT_8")
        self.SliderOUT_5 = QtWidgets.QSlider(self.centralwidget)
        self.SliderOUT_5.setEnabled(False)
        self.SliderOUT_5.setGeometry(QtCore.QRect(507, 275, 21, 138))
        self.SliderOUT_5.setMinimum(-95)
        self.SliderOUT_5.setMaximum(31)
        self.SliderOUT_5.setProperty("value", 0)
        self.SliderOUT_5.setOrientation(QtCore.Qt.Vertical)
        self.SliderOUT_5.setObjectName("SliderOUT_5")
        self.SliderOUT_7 = QtWidgets.QSlider(self.centralwidget)
        self.SliderOUT_7.setEnabled(False)
        self.SliderOUT_7.setGeometry(QtCore.QRect(617, 275, 21, 138))
        self.SliderOUT_7.setMinimum(-95)
        self.SliderOUT_7.setMaximum(31)
        self.SliderOUT_7.setProperty("value", 0)
        self.SliderOUT_7.setOrientation(QtCore.Qt.Vertical)
        self.SliderOUT_7.setObjectName("SliderOUT_7")
        self.SliderOUT_6 = QtWidgets.QSlider(self.centralwidget)
        self.SliderOUT_6.setEnabled(False)
        self.SliderOUT_6.setGeometry(QtCore.QRect(563, 275, 21, 138))
        self.SliderOUT_6.setMinimum(-95)
        self.SliderOUT_6.setMaximum(31)
        self.SliderOUT_6.setProperty("value", 0)
        self.SliderOUT_6.setOrientation(QtCore.Qt.Vertical)
        self.SliderOUT_6.setObjectName("SliderOUT_6")
        self.SliderOUT_2 = QtWidgets.QSlider(self.centralwidget)
        self.SliderOUT_2.setEnabled(False)
        self.SliderOUT_2.setGeometry(QtCore.QRect(342, 275, 21, 138))
        self.SliderOUT_2.setMinimum(-95)
        self.SliderOUT_2.setMaximum(31)
        self.SliderOUT_2.setProperty("value", 0)
        self.SliderOUT_2.setOrientation(QtCore.Qt.Vertical)
        self.SliderOUT_2.setObjectName("SliderOUT_2")
        self.SliderOUT_4 = QtWidgets.QSlider(self.centralwidget)
        self.SliderOUT_4.setEnabled(False)
        self.SliderOUT_4.setGeometry(QtCore.QRect(453, 275, 21, 138))
        self.SliderOUT_4.setMinimum(-95)
        self.SliderOUT_4.setMaximum(31)
        self.SliderOUT_4.setProperty("value", 0)
        self.SliderOUT_4.setOrientation(QtCore.Qt.Vertical)
        self.SliderOUT_4.setObjectName("SliderOUT_4")
        self.LucidMeterCombo = QtWidgets.QComboBox(self.centralwidget)
        self.LucidMeterCombo.setEnabled(False)
        self.LucidMeterCombo.setGeometry(QtCore.QRect(64, 93, 72, 20))
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(4)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.LucidMeterCombo.sizePolicy().hasHeightForWidth())
        self.LucidMeterCombo.setSizePolicy(sizePolicy)
        font = QtGui.QFont()
        font.setFamily("Source Sans Pro Light")
        font.setPointSize(7)
        font.setKerning(True)
        self.LucidMeterCombo.setFont(font)
        self.LucidMeterCombo.setEditable(False)
        self.LucidMeterCombo.setCurrentText("Analog IN")
        self.LucidMeterCombo.setIconSize(QtCore.QSize(0, 0))
        self.LucidMeterCombo.setFrame(False)
        self.LucidMeterCombo.setObjectName("LucidMeterCombo")
        self.LucidMeterCombo.addItem("")
        self.LucidMeterCombo.addItem("")
        self.LucidMeterCombo.addItem("")
        self.LucidMeterCombo.addItem("")
        self.LucidSyncCombo = QtWidgets.QComboBox(self.centralwidget)
        self.LucidSyncCombo.setEnabled(False)
        self.LucidSyncCombo.setGeometry(QtCore.QRect(64, 165, 72, 20))
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(4)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.LucidSyncCombo.sizePolicy().hasHeightForWidth())
        self.LucidSyncCombo.setSizePolicy(sizePolicy)
        font = QtGui.QFont()
        font.setFamily("Source Sans Pro Light")
        font.setPointSize(7)
        font.setKerning(True)
        self.LucidSyncCombo.setFont(font)
        self.LucidSyncCombo.setEditable(False)
        self.LucidSyncCombo.setCurrentText("ADAT")
        self.LucidSyncCombo.setIconSize(QtCore.QSize(0, 0))
        self.LucidSyncCombo.setFrame(False)
        self.LucidSyncCombo.setObjectName("LucidSyncCombo")
        self.LucidSyncCombo.addItem("")
        self.LucidSyncCombo.addItem("")
        self.LucidSyncCombo.addItem("")
        self.LucidSyncCombo.addItem("")
        self.LucidSyncCombo.addItem("")
        self.LucidSyncCombo.addItem("")
        self.LucidSyncCombo.addItem("")
        self.LucidSyncCombo.addItem("")
        self.LucidIdCombo = QtWidgets.QComboBox(self.centralwidget)
        self.LucidIdCombo.setEnabled(True)
        self.LucidIdCombo.setGeometry(QtCore.QRect(113, 298, 31, 22))
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(4)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.LucidIdCombo.sizePolicy().hasHeightForWidth())
        self.LucidIdCombo.setSizePolicy(sizePolicy)
        font = QtGui.QFont()
        font.setFamily("Source Sans Pro Light")
        font.setPointSize(7)
        font.setKerning(True)
        self.LucidIdCombo.setFont(font)
        self.LucidIdCombo.setEditable(False)
        self.LucidIdCombo.setCurrentText("00")
        self.LucidIdCombo.setIconSize(QtCore.QSize(0, 0))
        self.LucidIdCombo.setFrame(False)
        self.LucidIdCombo.setObjectName("LucidIdCombo")
        self.LucidIdCombo.addItem("")
        self.LucidIdCombo.addItem("")
        self.LucidIdCombo.addItem("")
        self.LucidIdCombo.addItem("")
        self.LucidIdCombo.addItem("")
        self.LucidIdCombo.addItem("")
        self.LucidIdCombo.addItem("")
        self.LucidIdCombo.addItem("")
        self.LucidSpdifCombo = QtWidgets.QComboBox(self.centralwidget)
        self.LucidSpdifCombo.setEnabled(False)
        self.LucidSpdifCombo.setGeometry(QtCore.QRect(730, 369, 75, 20))
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(4)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.LucidSpdifCombo.sizePolicy().hasHeightForWidth())
        self.LucidSpdifCombo.setSizePolicy(sizePolicy)
        font = QtGui.QFont()
        font.setFamily("Source Sans Pro Light")
        font.setPointSize(8)
        font.setKerning(True)
        self.LucidSpdifCombo.setFont(font)
        self.LucidSpdifCombo.setEditable(False)
        self.LucidSpdifCombo.setCurrentText("1,2 AES")
        self.LucidSpdifCombo.setIconSize(QtCore.QSize(0, 0))
        self.LucidSpdifCombo.setFrame(False)
        self.LucidSpdifCombo.setObjectName("LucidSpdifCombo")
        self.LucidSpdifCombo.addItem("")
        self.LucidSpdifCombo.addItem("")
        self.LucidAnalogSrcCombo = QtWidgets.QComboBox(self.centralwidget)
        self.LucidAnalogSrcCombo.setEnabled(False)
        self.LucidAnalogSrcCombo.setGeometry(QtCore.QRect(730, 295, 75, 20))
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(4)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.LucidAnalogSrcCombo.sizePolicy().hasHeightForWidth())
        self.LucidAnalogSrcCombo.setSizePolicy(sizePolicy)
        font = QtGui.QFont()
        font.setFamily("Source Sans Pro Light")
        font.setPointSize(9)
        font.setKerning(True)
        self.LucidAnalogSrcCombo.setFont(font)
        self.LucidAnalogSrcCombo.setEditable(False)
        self.LucidAnalogSrcCombo.setCurrentText("ADAT IN")
        self.LucidAnalogSrcCombo.setIconSize(QtCore.QSize(0, 0))
        self.LucidAnalogSrcCombo.setFrame(False)
        self.LucidAnalogSrcCombo.setObjectName("LucidAnalogSrcCombo")
        self.LucidAnalogSrcCombo.addItem("")
        self.LucidAnalogSrcCombo.addItem("")
        self.LucidOpticalCombo = QtWidgets.QComboBox(self.centralwidget)
        self.LucidOpticalCombo.setEnabled(False)
        self.LucidOpticalCombo.setGeometry(QtCore.QRect(730, 166, 75, 27))
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(4)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.LucidOpticalCombo.sizePolicy().hasHeightForWidth())
        self.LucidOpticalCombo.setSizePolicy(sizePolicy)
        font = QtGui.QFont()
        font.setFamily("Source Sans Pro Light")
        font.setPointSize(9)
        font.setKerning(True)
        self.LucidOpticalCombo.setFont(font)
        self.LucidOpticalCombo.setEditable(False)
        self.LucidOpticalCombo.setCurrentText("Analog IN")
        self.LucidOpticalCombo.setIconSize(QtCore.QSize(0, 0))
        self.LucidOpticalCombo.setFrame(False)
        self.LucidOpticalCombo.setObjectName("LucidOpticalCombo")
        self.LucidOpticalCombo.addItem("")
        self.LucidOpticalCombo.addItem("")
        self.LucidAesCombo = QtWidgets.QComboBox(self.centralwidget)
        self.LucidAesCombo.setEnabled(False)
        self.LucidAesCombo.setGeometry(QtCore.QRect(730, 115, 75, 28))
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(4)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.LucidAesCombo.sizePolicy().hasHeightForWidth())
        self.LucidAesCombo.setSizePolicy(sizePolicy)
        font = QtGui.QFont()
        font.setFamily("Source Sans Pro Light")
        font.setPointSize(9)
        font.setKerning(True)
        self.LucidAesCombo.setFont(font)
        self.LucidAesCombo.setEditable(False)
        self.LucidAesCombo.setCurrentText("ADAT IN")
        self.LucidAesCombo.setIconSize(QtCore.QSize(0, 0))
        self.LucidAesCombo.setFrame(False)
        self.LucidAesCombo.setObjectName("LucidAesCombo")
        self.LucidAesCombo.addItem("")
        self.LucidAesCombo.addItem("")
        self.ProINButton = QtWidgets.QPushButton(self.centralwidget)
        self.ProINButton.setEnabled(False)
        self.ProINButton.setGeometry(QtCore.QRect(180, 96, 70, 37))
        self.ProINButton.setObjectName("ProINButton")
        self.ConINButton = QtWidgets.QPushButton(self.centralwidget)
        self.ConINButton.setEnabled(False)
        self.ConINButton.setGeometry(QtCore.QRect(180, 136, 70, 37))
        self.ConINButton.setObjectName("ConINButton")
        self.LinkInCh = QtWidgets.QCheckBox(self.centralwidget)
        self.LinkInCh.setEnabled(False)
        self.LinkInCh.setGeometry(QtCore.QRect(208, 175, 35, 26))
        self.LinkInCh.setText("")
        self.LinkInCh.setChecked(True)
        self.LinkInCh.setObjectName("LinkInCh")
        self.LinkOutCh = QtWidgets.QCheckBox(self.centralwidget)
        self.LinkOutCh.setEnabled(False)
        self.LinkOutCh.setGeometry(QtCore.QRect(210, 376, 35, 26))
        self.LinkOutCh.setText("")
        self.LinkOutCh.setChecked(True)
        self.LinkOutCh.setObjectName("LinkOutCh")
        self.ProOUTButton = QtWidgets.QPushButton(self.centralwidget)
        self.ProOUTButton.setEnabled(False)
        self.ProOUTButton.setGeometry(QtCore.QRect(180, 297, 70, 37))
        self.ProOUTButton.setObjectName("ProOUTButton")
        self.ConOUTButton = QtWidgets.QPushButton(self.centralwidget)
        self.ConOUTButton.setEnabled(False)
        self.ConOUTButton.setGeometry(QtCore.QRect(180, 337, 70, 37))
        self.ConOUTButton.setObjectName("ConOUTButton")
        self.LucidReadButton = QtWidgets.QPushButton(self.centralwidget)
        self.LucidReadButton.setGeometry(QtCore.QRect(69, 324, 70, 38))
        self.LucidReadButton.setObjectName("LucidReadButton")
        self.LucidWriteButton = QtWidgets.QPushButton(self.centralwidget)
        self.LucidWriteButton.setEnabled(False)
        self.LucidWriteButton.setGeometry(QtCore.QRect(69, 364, 70, 38))
        self.LucidWriteButton.setObjectName("LucidWriteButton")
        self.labelIN_1 = xglucidLabel(self.centralwidget)
        self.labelIN_1.setGeometry(QtCore.QRect(285, 219, 41, 21))
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.labelIN_1.sizePolicy().hasHeightForWidth())
        self.labelIN_1.setSizePolicy(sizePolicy)
        font = QtGui.QFont()
        font.setPointSize(8)
        self.labelIN_1.setFont(font)
        self.labelIN_1.setText("")
        self.labelIN_1.setObjectName("labelIN_1")
        self.labelIN_2 = xglucidLabel(self.centralwidget)
        self.labelIN_2.setGeometry(QtCore.QRect(340, 219, 41, 21))
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.labelIN_2.sizePolicy().hasHeightForWidth())
        self.labelIN_2.setSizePolicy(sizePolicy)
        font = QtGui.QFont()
        font.setPointSize(8)
        self.labelIN_2.setFont(font)
        self.labelIN_2.setText("")
        self.labelIN_2.setObjectName("labelIN_2")
        self.labelIN_4 = xglucidLabel(self.centralwidget)
        self.labelIN_4.setGeometry(QtCore.QRect(449, 219, 41, 21))
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.labelIN_4.sizePolicy().hasHeightForWidth())
        self.labelIN_4.setSizePolicy(sizePolicy)
        font = QtGui.QFont()
        font.setPointSize(8)
        self.labelIN_4.setFont(font)
        self.labelIN_4.setText("")
        self.labelIN_4.setObjectName("labelIN_4")
        self.labelIN_3 = xglucidLabel(self.centralwidget)
        self.labelIN_3.setGeometry(QtCore.QRect(395, 219, 41, 21))
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.labelIN_3.sizePolicy().hasHeightForWidth())
        self.labelIN_3.setSizePolicy(sizePolicy)
        font = QtGui.QFont()
        font.setPointSize(8)
        self.labelIN_3.setFont(font)
        self.labelIN_3.setText("")
        self.labelIN_3.setObjectName("labelIN_3")
        self.labelIN_6 = xglucidLabel(self.centralwidget)
        self.labelIN_6.setGeometry(QtCore.QRect(560, 219, 41, 21))
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.labelIN_6.sizePolicy().hasHeightForWidth())
        self.labelIN_6.setSizePolicy(sizePolicy)
        font = QtGui.QFont()
        font.setPointSize(8)
        self.labelIN_6.setFont(font)
        self.labelIN_6.setText("")
        self.labelIN_6.setObjectName("labelIN_6")
        self.labelIN_8 = xglucidLabel(self.centralwidget)
        self.labelIN_8.setGeometry(QtCore.QRect(667, 219, 41, 21))
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.labelIN_8.sizePolicy().hasHeightForWidth())
        self.labelIN_8.setSizePolicy(sizePolicy)
        font = QtGui.QFont()
        font.setPointSize(8)
        self.labelIN_8.setFont(font)
        self.labelIN_8.setText("")
        self.labelIN_8.setObjectName("labelIN_8")
        self.labelIN_5 = xglucidLabel(self.centralwidget)
        self.labelIN_5.setGeometry(QtCore.QRect(505, 219, 41, 21))
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.labelIN_5.sizePolicy().hasHeightForWidth())
        self.labelIN_5.setSizePolicy(sizePolicy)
        font = QtGui.QFont()
        font.setPointSize(8)
        self.labelIN_5.setFont(font)
        self.labelIN_5.setText("")
        self.labelIN_5.setObjectName("labelIN_5")
        self.labelIN_7 = xglucidLabel(self.centralwidget)
        self.labelIN_7.setGeometry(QtCore.QRect(612, 219, 41, 21))
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.labelIN_7.sizePolicy().hasHeightForWidth())
        self.labelIN_7.setSizePolicy(sizePolicy)
        font = QtGui.QFont()
        font.setPointSize(8)
        self.labelIN_7.setFont(font)
        self.labelIN_7.setText("")
        self.labelIN_7.setObjectName("labelIN_7")
        self.labelOUT_2 = xglucidLabel(self.centralwidget)
        self.labelOUT_2.setGeometry(QtCore.QRect(340, 415, 41, 21))
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.labelOUT_2.sizePolicy().hasHeightForWidth())
        self.labelOUT_2.setSizePolicy(sizePolicy)
        font = QtGui.QFont()
        font.setPointSize(8)
        self.labelOUT_2.setFont(font)
        self.labelOUT_2.setText("")
        self.labelOUT_2.setObjectName("labelOUT_2")
        self.labelOUT_8 = xglucidLabel(self.centralwidget)
        self.labelOUT_8.setGeometry(QtCore.QRect(671, 415, 41, 21))
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.labelOUT_8.sizePolicy().hasHeightForWidth())
        self.labelOUT_8.setSizePolicy(sizePolicy)
        font = QtGui.QFont()
        font.setPointSize(8)
        self.labelOUT_8.setFont(font)
        self.labelOUT_8.setText("")
        self.labelOUT_8.setObjectName("labelOUT_8")
        self.labelOUT_4 = xglucidLabel(self.centralwidget)
        self.labelOUT_4.setGeometry(QtCore.QRect(451, 415, 41, 21))
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.labelOUT_4.sizePolicy().hasHeightForWidth())
        self.labelOUT_4.setSizePolicy(sizePolicy)
        font = QtGui.QFont()
        font.setPointSize(8)
        self.labelOUT_4.setFont(font)
        self.labelOUT_4.setText("")
        self.labelOUT_4.setObjectName("labelOUT_4")
        self.labelOUT_1 = xglucidLabel(self.centralwidget)
        self.labelOUT_1.setGeometry(QtCore.QRect(286, 415, 41, 21))
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.labelOUT_1.sizePolicy().hasHeightForWidth())
        self.labelOUT_1.setSizePolicy(sizePolicy)
        font = QtGui.QFont()
        font.setPointSize(8)
        self.labelOUT_1.setFont(font)
        self.labelOUT_1.setText("")
        self.labelOUT_1.setObjectName("labelOUT_1")
        self.labelOUT_7 = xglucidLabel(self.centralwidget)
        self.labelOUT_7.setGeometry(QtCore.QRect(618, 415, 41, 21))
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.labelOUT_7.sizePolicy().hasHeightForWidth())
        self.labelOUT_7.setSizePolicy(sizePolicy)
        font = QtGui.QFont()
        font.setPointSize(8)
        self.labelOUT_7.setFont(font)
        self.labelOUT_7.setText("")
        self.labelOUT_7.setObjectName("labelOUT_7")
        self.labelOUT_5 = xglucidLabel(self.centralwidget)
        self.labelOUT_5.setGeometry(QtCore.QRect(506, 415, 41, 21))
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.labelOUT_5.sizePolicy().hasHeightForWidth())
        self.labelOUT_5.setSizePolicy(sizePolicy)
        font = QtGui.QFont()
        font.setPointSize(8)
        self.labelOUT_5.setFont(font)
        self.labelOUT_5.setText("")
        self.labelOUT_5.setObjectName("labelOUT_5")
        self.labelOUT_6 = xglucidLabel(self.centralwidget)
        self.labelOUT_6.setGeometry(QtCore.QRect(561, 415, 41, 21))
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.labelOUT_6.sizePolicy().hasHeightForWidth())
        self.labelOUT_6.setSizePolicy(sizePolicy)
        font = QtGui.QFont()
        font.setPointSize(8)
        self.labelOUT_6.setFont(font)
        self.labelOUT_6.setText("")
        self.labelOUT_6.setObjectName("labelOUT_6")
        self.labelOUT_3 = xglucidLabel(self.centralwidget)
        self.labelOUT_3.setGeometry(QtCore.QRect(395, 415, 41, 21))
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.labelOUT_3.sizePolicy().hasHeightForWidth())
        self.labelOUT_3.setSizePolicy(sizePolicy)
        font = QtGui.QFont()
        font.setPointSize(8)
        self.labelOUT_3.setFont(font)
        self.labelOUT_3.setText("")
        self.labelOUT_3.setObjectName("labelOUT_3")
        self.label_18 = QtWidgets.QLabel(self.centralwidget)
        self.label_18.setGeometry(QtCore.QRect(0, -209, 900, 516))
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.MinimumExpanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.label_18.sizePolicy().hasHeightForWidth())
        self.label_18.setSizePolicy(sizePolicy)
        self.label_18.setMaximumSize(QtCore.QSize(904, 895))
        self.label_18.setObjectName("label_18")
        self.SerialPortCombo = QtWidgets.QComboBox(self.centralwidget)
        self.SerialPortCombo.setGeometry(QtCore.QRect(65, 227, 81, 28))
        font = QtGui.QFont()
        font.setPointSize(6)
        self.SerialPortCombo.setFont(font)
        self.SerialPortCombo.setObjectName("SerialPortCombo")
        self.SerialPortCombo.addItem("")
        self.SerialPortCombo.addItem("")
        self.SerialPortCombo.addItem("")
        self.SerialPortCombo.addItem("")
        self.SerialPortCombo.addItem("")
        self.SerialPortCombo.addItem("")
        self.SerialPortCombo.addItem("")
        self.SerialPortCombo.addItem("")
        self.SerialPortCombo.addItem("")
        self.SerialPortCombo.addItem("")
        self.SerialPortCombo.addItem("")
        self.SerialPortCombo.addItem("")
        self.SerialPortCombo.addItem("")
        self.SerialPortCombo.addItem("")
        self.SerialPortCombo.addItem("")
        self.SerialPortCombo.addItem("")
        self.SerialPortCombo.addItem("")
        self.SerialPortCombo.addItem("")
        self.SerialPortCombo.addItem("")
        self.SerialPortCombo.addItem("")
        self.SerialPortCombo.addItem("")
        self.SerialPortCombo.addItem("")
        self.SerialPortCombo.addItem("")
        self.SerialPortCombo.addItem("")
        self.SerialPortCombo.addItem("")
        self.SerialPortCombo.addItem("")
        self.SerialPortCombo.addItem("")
        self.SerialPortCombo.addItem("")
        self.SerialPortCombo.addItem("")
        self.SerialPortCombo.addItem("")
        self.SerialPortCombo.addItem("")
        self.SerialPortCombo.addItem("")
        self.SerialPortCombo.addItem("")
        self.SerialPortCombo.addItem("")
        self.SerialPortCombo.addItem("")
        self.connection_label = QtWidgets.QLabel(self.centralwidget)
        self.connection_label.setGeometry(QtCore.QRect(72, 270, 71, 20))
        self.connection_label.setObjectName("connection_label")
        self.label_18.raise_()
        self.label.raise_()
        self.labelIN_1.raise_()
        self.labelIN_2.raise_()
        self.labelIN_4.raise_()
        self.labelIN_3.raise_()
        self.labelIN_6.raise_()
        self.labelIN_8.raise_()
        self.labelIN_5.raise_()
        self.labelIN_7.raise_()
        self.labelOUT_2.raise_()
        self.labelOUT_8.raise_()
        self.labelOUT_4.raise_()
        self.labelOUT_1.raise_()
        self.labelOUT_7.raise_()
        self.labelOUT_5.raise_()
        self.labelOUT_6.raise_()
        self.labelOUT_3.raise_()
        self.SliderIN_7.raise_()
        self.SliderIN_3.raise_()
        self.SliderOUT_8.raise_()
        self.SliderOUT_2.raise_()
        self.ConOUTButton.raise_()
        self.SliderOUT_7.raise_()
        self.SliderOUT_5.raise_()
        self.SliderOUT_3.raise_()
        self.SliderOUT_1.raise_()
        self.SliderIN_1.raise_()
        self.ProINButton.raise_()
        self.LucidReadButton.raise_()
        self.ProOUTButton.raise_()
        self.SliderIN_4.raise_()
        self.LucidWriteButton.raise_()
        self.SliderIN_6.raise_()
        self.ConINButton.raise_()
        self.SliderOUT_6.raise_()
        self.SliderIN_5.raise_()
        self.SliderIN_2.raise_()
        self.SliderIN_8.raise_()
        self.SliderOUT_4.raise_()
        self.LucidOpticalCombo.raise_()
        self.LucidSpdifCombo.raise_()
        self.LinkOutCh.raise_()
        self.LucidIdCombo.raise_()
        self.LucidMeterCombo.raise_()
        self.LucidAesCombo.raise_()
        self.LinkInCh.raise_()
        self.LucidSyncCombo.raise_()
        self.LucidAnalogSrcCombo.raise_()
        self.SerialPortCombo.raise_()
        self.connection_label.raise_()
        self.statusbar = QtWidgets.QStatusBar(MainWindow)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.MinimumExpanding, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.statusbar.sizePolicy().hasHeightForWidth())
        self.statusbar.setSizePolicy(sizePolicy)
        self.statusbar.setSizeGripEnabled(False)
        self.statusbar.setObjectName("statusbar")
        MainWindow.setStatusBar(self.statusbar)
        self.action_dev_ttyUSB0 = QtWidgets.QAction(MainWindow)
        self.action_dev_ttyUSB0.setCheckable(True)
        self.action_dev_ttyUSB0.setChecked(True)
        self.action_dev_ttyUSB0.setObjectName("action_dev_ttyUSB0")
        self.action_dev_ttyUSB1 = QtWidgets.QAction(MainWindow)
        self.action_dev_ttyUSB1.setCheckable(True)
        self.action_dev_ttyUSB1.setObjectName("action_dev_ttyUSB1")
        self.action_dev_ttyUSB2 = QtWidgets.QAction(MainWindow)
        self.action_dev_ttyUSB2.setCheckable(True)
        self.action_dev_ttyUSB2.setObjectName("action_dev_ttyUSB2")
        self.action_dev_ttyUSB3 = QtWidgets.QAction(MainWindow)
        self.action_dev_ttyUSB3.setCheckable(True)
        self.action_dev_ttyUSB3.setObjectName("action_dev_ttyUSB3")
        self.action_dev_ttyUSB4 = QtWidgets.QAction(MainWindow)
        self.action_dev_ttyUSB4.setCheckable(True)
        self.action_dev_ttyUSB4.setObjectName("action_dev_ttyUSB4")
        self.action_dev_ttyUSB4_2 = QtWidgets.QAction(MainWindow)
        self.action_dev_ttyUSB4_2.setObjectName("action_dev_ttyUSB4_2")
        self.action_dev_ttyUSB5 = QtWidgets.QAction(MainWindow)
        self.action_dev_ttyUSB5.setCheckable(True)
        self.action_dev_ttyUSB5.setObjectName("action_dev_ttyUSB5")
        self.action_dev_ttyS0 = QtWidgets.QAction(MainWindow)
        self.action_dev_ttyS0.setCheckable(True)
        self.action_dev_ttyS0.setObjectName("action_dev_ttyS0")
        self.action_dev_ttyS1 = QtWidgets.QAction(MainWindow)
        self.action_dev_ttyS1.setCheckable(True)
        self.action_dev_ttyS1.setObjectName("action_dev_ttyS1")
        self.action_dev_ttyS2 = QtWidgets.QAction(MainWindow)
        self.action_dev_ttyS2.setCheckable(True)
        self.action_dev_ttyS2.setObjectName("action_dev_ttyS2")
        self.action_dev_ttyS3 = QtWidgets.QAction(MainWindow)
        self.action_dev_ttyS3.setCheckable(True)
        self.action_dev_ttyS3.setObjectName("action_dev_ttyS3")
        self.action_dev_ttyS4 = QtWidgets.QAction(MainWindow)
        self.action_dev_ttyS4.setCheckable(True)
        self.action_dev_ttyS4.setObjectName("action_dev_ttyS4")
        self.action_dev_ttyS5 = QtWidgets.QAction(MainWindow)
        self.action_dev_ttyS5.setCheckable(True)
        self.action_dev_ttyS5.setObjectName("action_dev_ttyS5")
        self.action_dev_ttyAMA0 = QtWidgets.QAction(MainWindow)
        self.action_dev_ttyAMA0.setCheckable(True)
        self.action_dev_ttyAMA0.setObjectName("action_dev_ttyAMA0")
        self.action_dev_ttyAMA1 = QtWidgets.QAction(MainWindow)
        self.action_dev_ttyAMA1.setCheckable(True)
        self.action_dev_ttyAMA1.setObjectName("action_dev_ttyAMA1")
        self.action_dev_ttyACM0 = QtWidgets.QAction(MainWindow)
        self.action_dev_ttyACM0.setCheckable(True)
        self.action_dev_ttyACM0.setObjectName("action_dev_ttyACM0")
        self.action_dev_ttyACM1 = QtWidgets.QAction(MainWindow)
        self.action_dev_ttyACM1.setCheckable(True)
        self.action_dev_ttyACM1.setObjectName("action_dev_ttyACM1")
        self.action_dev_rfcomm0 = QtWidgets.QAction(MainWindow)
        self.action_dev_rfcomm0.setCheckable(True)
        self.action_dev_rfcomm0.setObjectName("action_dev_rfcomm0")
        self.action_dev_ircomm0 = QtWidgets.QAction(MainWindow)
        self.action_dev_ircomm0.setCheckable(True)
        self.action_dev_ircomm0.setObjectName("action_dev_ircomm0")
        self.action_dev_cuau0 = QtWidgets.QAction(MainWindow)
        self.action_dev_cuau0.setCheckable(True)
        self.action_dev_cuau0.setObjectName("action_dev_cuau0")

        self.retranslateUi(MainWindow)
        self.SliderIN_1.valueChanged['int'].connect(self.labelIN_1.on_slider_value_changed)
        self.SliderIN_2.valueChanged['int'].connect(self.labelIN_2.on_slider_value_changed)
        self.LucidWriteButton.clicked.connect(self.statusbar.clearMessage)
        self.SliderOUT_1.valueChanged['int'].connect(self.labelOUT_1.on_slider_value_changed)
        self.SliderIN_3.valueChanged['int'].connect(self.labelIN_3.on_slider_value_changed)
        self.SliderIN_4.valueChanged['int'].connect(self.labelIN_4.on_slider_value_changed)
        self.SliderIN_5.valueChanged['int'].connect(self.labelIN_5.on_slider_value_changed)
        self.SliderIN_6.valueChanged['int'].connect(self.labelIN_6.on_slider_value_changed)
        self.SliderIN_7.valueChanged['int'].connect(self.labelIN_7.on_slider_value_changed)
        self.SliderIN_8.valueChanged['int'].connect(self.labelIN_8.on_slider_value_changed)
        self.LucidReadButton.clicked.connect(self.statusbar.clearMessage)
        self.SliderOUT_2.valueChanged['int'].connect(self.labelOUT_2.on_slider_value_changed)
        self.SliderOUT_3.valueChanged['int'].connect(self.labelOUT_3.on_slider_value_changed)
        self.SliderOUT_4.valueChanged['int'].connect(self.labelOUT_4.on_slider_value_changed)
        self.SliderOUT_5.valueChanged['int'].connect(self.labelOUT_5.on_slider_value_changed)
        self.SliderOUT_6.valueChanged['int'].connect(self.labelOUT_6.on_slider_value_changed)
        self.SliderOUT_7.valueChanged['int'].connect(self.labelOUT_7.on_slider_value_changed)
        self.SliderOUT_8.valueChanged['int'].connect(self.labelOUT_8.on_slider_value_changed)
        self.SliderIN_1.valueChanged['int'].connect(self.centralwidget.on_glucid_slider_changed)
        self.SliderIN_2.valueChanged['int'].connect(self.centralwidget.on_glucid_slider_changed)
        self.SliderIN_3.valueChanged['int'].connect(self.centralwidget.on_glucid_slider_changed)
        self.SliderIN_4.valueChanged['int'].connect(self.centralwidget.on_glucid_slider_changed)
        self.SliderIN_8.valueChanged['int'].connect(self.centralwidget.on_glucid_slider_changed)
        self.SliderIN_7.valueChanged['int'].connect(self.centralwidget.on_glucid_slider_changed)
        self.SliderIN_6.valueChanged['int'].connect(self.centralwidget.on_glucid_slider_changed)
        self.SliderIN_5.valueChanged['int'].connect(self.centralwidget.on_glucid_slider_changed)
        self.SliderOUT_1.valueChanged['int'].connect(self.centralwidget.on_glucid_slider_changed)
        self.SliderOUT_8.valueChanged['int'].connect(self.centralwidget.on_glucid_slider_changed)
        self.SliderOUT_7.valueChanged['int'].connect(self.centralwidget.on_glucid_slider_changed)
        self.SliderOUT_6.valueChanged['int'].connect(self.centralwidget.on_glucid_slider_changed)
        self.SliderOUT_5.valueChanged['int'].connect(self.centralwidget.on_glucid_slider_changed)
        self.SliderOUT_4.valueChanged['int'].connect(self.centralwidget.on_glucid_slider_changed)
        self.SliderOUT_3.valueChanged['int'].connect(self.centralwidget.on_glucid_slider_changed)
        self.SliderOUT_2.valueChanged['int'].connect(self.centralwidget.on_glucid_slider_changed)
        self.LucidReadButton.clicked.connect(self.centralwidget.read_button_clicked)
        self.LucidWriteButton.clicked.connect(self.centralwidget.write_button_clicked)
        self.SerialPortCombo.currentTextChanged['QString'].connect(self.centralwidget.on_serial_port_changed)
        self.ProOUTButton.clicked.connect(self.centralwidget.pro_or_consumer_clicked)
        self.ConINButton.clicked.connect(self.centralwidget.pro_or_consumer_clicked)
        self.ConOUTButton.clicked.connect(self.centralwidget.pro_or_consumer_clicked)
        self.ProINButton.clicked.connect(self.centralwidget.pro_or_consumer_clicked)
        QtCore.QMetaObject.connectSlotsByName(MainWindow)

    def retranslateUi(self, MainWindow):
        _translate = QtCore.QCoreApplication.translate
        MainWindow.setWindowTitle(_translate("MainWindow", "xglucid"))
        self.LucidMeterCombo.setItemText(0, _translate("MainWindow", "Analog IN"))
        self.LucidMeterCombo.setItemText(1, _translate("MainWindow", "Digital IN"))
        self.LucidMeterCombo.setItemText(2, _translate("MainWindow", "Analog OUT"))
        self.LucidMeterCombo.setItemText(3, _translate("MainWindow", "Digital OUT"))
        self.LucidSyncCombo.setItemText(0, _translate("MainWindow", "ADAT"))
        self.LucidSyncCombo.setItemText(1, _translate("MainWindow", "WordClock"))
        self.LucidSyncCombo.setItemText(2, _translate("MainWindow", "44.1 Int"))
        self.LucidSyncCombo.setItemText(3, _translate("MainWindow", "48 Int"))
        self.LucidSyncCombo.setItemText(4, _translate("MainWindow", "AES In1"))
        self.LucidSyncCombo.setItemText(5, _translate("MainWindow", "AES In2"))
        self.LucidSyncCombo.setItemText(6, _translate("MainWindow", "AES In3"))
        self.LucidSyncCombo.setItemText(7, _translate("MainWindow", "S/PDIF "))
        self.LucidIdCombo.setItemText(0, _translate("MainWindow", "00"))
        self.LucidIdCombo.setItemText(1, _translate("MainWindow", "01"))
        self.LucidIdCombo.setItemText(2, _translate("MainWindow", "02"))
        self.LucidIdCombo.setItemText(3, _translate("MainWindow", "03"))
        self.LucidIdCombo.setItemText(4, _translate("MainWindow", "04"))
        self.LucidIdCombo.setItemText(5, _translate("MainWindow", "05"))
        self.LucidIdCombo.setItemText(6, _translate("MainWindow", "06"))
        self.LucidIdCombo.setItemText(7, _translate("MainWindow", "07"))
        self.LucidSpdifCombo.setItemText(0, _translate("MainWindow", "1,2 AES"))
        self.LucidSpdifCombo.setItemText(1, _translate("MainWindow", "1,2 S/PDIF"))
        self.LucidAnalogSrcCombo.setItemText(0, _translate("MainWindow", "ADAT IN"))
        self.LucidAnalogSrcCombo.setItemText(1, _translate("MainWindow", "AES IN"))
        self.LucidOpticalCombo.setItemText(0, _translate("MainWindow", "Analog IN"))
        self.LucidOpticalCombo.setItemText(1, _translate("MainWindow", "AES IN"))
        self.LucidAesCombo.setItemText(0, _translate("MainWindow", "ADAT IN"))
        self.LucidAesCombo.setItemText(1, _translate("MainWindow", "Analog IN"))
        self.ProINButton.setText(_translate("MainWindow", "+4 dBu"))
        self.ConINButton.setText(_translate("MainWindow", "-10 dBV"))
        self.ProOUTButton.setText(_translate("MainWindow", "+4 dBu"))
        self.ConOUTButton.setText(_translate("MainWindow", "-10 dBV"))
        self.LucidReadButton.setText(_translate("MainWindow", "READ"))
        self.LucidWriteButton.setText(_translate("MainWindow", "WRITE"))
        self.label_18.setText(_translate("MainWindow", "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.0//EN\" \"http://www.w3.org/TR/REC-html40/strict.dtd\">\n"
"<html><head><meta name=\"qrichtext\" content=\"1\" /><style type=\"text/css\">\n"
"p, li { white-space: pre-wrap; }\n"
"</style></head><body style=\" font-family:\'Cantarell\'; font-size:11pt; font-weight:400; font-style:normal;\">\n"
"<p align=\"center\" dir=\'rtl\' style=\" margin-top:12px; margin-bottom:12px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><img src=\":/newPrefix/glucidLayout2-smallsig.png\" /></p></body></html>"))
        self.SerialPortCombo.setItemText(0, _translate("MainWindow", "/dev/ttyUSB0"))
        self.SerialPortCombo.setItemText(1, _translate("MainWindow", "/dev/tty.usbserial"))
        self.SerialPortCombo.setItemText(2, _translate("MainWindow", "/dev/cu.usbserial"))
        self.SerialPortCombo.setItemText(3, _translate("MainWindow", "COM1"))
        self.SerialPortCombo.setItemText(4, _translate("MainWindow", "/dev/midi1"))
        self.SerialPortCombo.setItemText(5, _translate("MainWindow", "/dev/snd/midiC1D0"))
        self.SerialPortCombo.setItemText(6, _translate("MainWindow", "MIDIOUT2"))
        self.SerialPortCombo.setItemText(7, _translate("MainWindow", "/dev/ttyUSB1"))
        self.SerialPortCombo.setItemText(8, _translate("MainWindow", "/dev/ttyUSB2"))
        self.SerialPortCombo.setItemText(9, _translate("MainWindow", "/dev/ttyUSB3"))
        self.SerialPortCombo.setItemText(10, _translate("MainWindow", "/dev/ttyUSB4"))
        self.SerialPortCombo.setItemText(11, _translate("MainWindow", "/dev/ttyUSB5"))
        self.SerialPortCombo.setItemText(12, _translate("MainWindow", "/dev/ttyS0"))
        self.SerialPortCombo.setItemText(13, _translate("MainWindow", "/dev/ttyS1"))
        self.SerialPortCombo.setItemText(14, _translate("MainWindow", "/dev/ttyS2"))
        self.SerialPortCombo.setItemText(15, _translate("MainWindow", "/dev/ttyS3"))
        self.SerialPortCombo.setItemText(16, _translate("MainWindow", "/dev/ttyS4"))
        self.SerialPortCombo.setItemText(17, _translate("MainWindow", "/dev/ttyS5"))
        self.SerialPortCombo.setItemText(18, _translate("MainWindow", "/dev/ttyAMA0"))
        self.SerialPortCombo.setItemText(19, _translate("MainWindow", "/dev/ttyAMA1"))
        self.SerialPortCombo.setItemText(20, _translate("MainWindow", "/dev/ttyACM0"))
        self.SerialPortCombo.setItemText(21, _translate("MainWindow", "/dev/ttyACM1"))
        self.SerialPortCombo.setItemText(22, _translate("MainWindow", "/dev/rfcomm0"))
        self.SerialPortCombo.setItemText(23, _translate("MainWindow", "/dev/rfcomm1"))
        self.SerialPortCombo.setItemText(24, _translate("MainWindow", "/dev/ircomm0"))
        self.SerialPortCombo.setItemText(25, _translate("MainWindow", "/dev/ircomm1"))
        self.SerialPortCombo.setItemText(26, _translate("MainWindow", "/dev/cuau0"))
        self.SerialPortCombo.setItemText(27, _translate("MainWindow", "/dev/cuau1"))
        self.SerialPortCombo.setItemText(28, _translate("MainWindow", "/dev/cuau2"))
        self.SerialPortCombo.setItemText(29, _translate("MainWindow", "/dev/cuaU0"))
        self.SerialPortCombo.setItemText(30, _translate("MainWindow", "/dev/cuaU1"))
        self.SerialPortCombo.setItemText(31, _translate("MainWindow", "COM1"))
        self.SerialPortCombo.setItemText(32, _translate("MainWindow", "COM2"))
        self.SerialPortCombo.setItemText(33, _translate("MainWindow", "COM3"))
        self.SerialPortCombo.setItemText(34, _translate("MainWindow", "COM4"))
        self.connection_label.setText(_translate("MainWindow", "NONE"))
        self.action_dev_ttyUSB0.setText(_translate("MainWindow", "/dev/ttyUSB0"))
        self.action_dev_ttyUSB1.setText(_translate("MainWindow", "/dev/ttyUSB1"))
        self.action_dev_ttyUSB2.setText(_translate("MainWindow", "/dev/ttyUSB2"))
        self.action_dev_ttyUSB3.setText(_translate("MainWindow", "/dev/ttyUSB3"))
        self.action_dev_ttyUSB4.setText(_translate("MainWindow", "/dev/ttyUSB4"))
        self.action_dev_ttyUSB4_2.setText(_translate("MainWindow", "/dev/ttyUSB4"))
        self.action_dev_ttyUSB5.setText(_translate("MainWindow", "/dev/ttyUSB5"))
        self.action_dev_ttyS0.setText(_translate("MainWindow", "/dev/ttyS0"))
        self.action_dev_ttyS1.setText(_translate("MainWindow", "/dev/ttyS1"))
        self.action_dev_ttyS2.setText(_translate("MainWindow", "/dev/ttyS2"))
        self.action_dev_ttyS3.setText(_translate("MainWindow", "/dev/ttyS3"))
        self.action_dev_ttyS4.setText(_translate("MainWindow", "/dev/ttyS4"))
        self.action_dev_ttyS5.setText(_translate("MainWindow", "/dev/ttyS5"))
        self.action_dev_ttyAMA0.setText(_translate("MainWindow", "/dev/ttyAMA0"))
        self.action_dev_ttyAMA1.setText(_translate("MainWindow", "/dev/ttyAMA1"))
        self.action_dev_ttyACM0.setText(_translate("MainWindow", "/dev/ttyACM0"))
        self.action_dev_ttyACM1.setText(_translate("MainWindow", "/dev/ttyACM1"))
        self.action_dev_rfcomm0.setText(_translate("MainWindow", "/dev/rfcomm0"))
        self.action_dev_ircomm0.setText(_translate("MainWindow", "/dev/ircomm0"))
        self.action_dev_cuau0.setText(_translate("MainWindow", "/dev/cuau0"))

from glucid.xglucidUIWidgets import xglucidLabel, xglucidWidget
from glucid import Glucid8824_rc
